@@ -7,9 +7,16 @@ import sys
 import os
 import pickle
 import datetime
+import time
 import alarm
 
+### Currently on pyside!
+# All temporary changes commented and markes with "###pyside###"
+
+###pyside###
 from PySide import QtCore, QtGui, QtMaemo5
+#~ from PyQt4 import QtCore, QtGui
+###pyside###
 
 # recurrence types
 only_once = "Only once"
@@ -36,6 +43,8 @@ sat = "Saturday"
 sun = "Sunday"
 # builtin functions
 gprsdataresetter = "Reset GPRS data counter"
+offlineswitcher = "Enable flight mode"
+onlineswitcher = "Disable flight mode"
 
 class DataCounterResetter(QtGui.QWidget):
     def __init__(self, parent=None):
@@ -109,11 +118,16 @@ class DataCounterResetter(QtGui.QWidget):
                      QtCore.SIGNAL("activated(int)"),
                      self.updateDatePicker)
         
+        ###pyside###
         self.dateButton = QtMaemo5.QMaemo5ValueButton("Date")
         self.dateButton.setValueLayout(
                         QtMaemo5.QMaemo5ValueButton.ValueUnderText)
         self.datePicker = QtMaemo5.QMaemo5DatePickSelector()
         self.dateButton.setPickSelector(self.datePicker)
+        #~ self.dateButton = QtGui.QDateEdit()
+        #~ self.dateButton.setDate(QtCore.QDate(
+                                #~ datetime.date.today()))
+        ###pyside###
         
         self.weekdayButton = QtGui.QPushButton("Days of week")
         self.connect(self.weekdayButton, QtCore.SIGNAL("clicked()"),
@@ -121,11 +135,16 @@ class DataCounterResetter(QtGui.QWidget):
         self.weekdayButton.hide()
         self.weekdays = []
         
+        ###pyside###
         self.timeButton = QtMaemo5.QMaemo5ValueButton("Time")
         self.timeButton.setValueLayout(
                         QtMaemo5.QMaemo5ValueButton.ValueUnderText)
         self.timePicker = QtMaemo5.QMaemo5TimePickSelector()
         self.timeButton.setPickSelector(self.timePicker)
+        #~ self.timeButton = QtGui.QTimeEdit(QtCore.QTime(
+                                          #~ time.localtime()[3],
+                                          #~ time.localtime()[4]))
+        ###pyside###
         
         self.eventName = QtGui.QLineEdit("Enter name")
         self.eventDbusInterface = QtGui.QLineEdit("Interface")
@@ -136,6 +155,8 @@ class DataCounterResetter(QtGui.QWidget):
         self.eventExec = QtGui.QLineEdit("Enter command")
         self.eventBuiltin = QtGui.QComboBox()
         self.eventBuiltin.addItem(gprsdataresetter)
+        self.eventBuiltin.addItem(offlineswitcher)
+        self.eventBuiltin.addItem(onlineswitcher)
         self.eventDbusInterface.hide()
         self.eventDbusService.hide()
         self.eventDbusPath.hide()
@@ -147,31 +168,31 @@ class DataCounterResetter(QtGui.QWidget):
         self.addButton = QtGui.QPushButton("Add")
         self.connect(self.addButton, QtCore.SIGNAL("clicked()"),
                      self.setAlarmEvent)
-        self.dateHBox = QtGui.QHBoxLayout()
-        self.dateHBox.addWidget(self.typePicker)
-        self.dateHBox.addWidget(self.intervalPicker)
-        self.dateHBox.addWidget(self.dateButton)
-        self.dateHBox.addWidget(self.weekdayButton)
-        self.dateHBox.addWidget(self.timeButton)
-        self.nameAddHBox = QtGui.QHBoxLayout()
-        self.nameAddHBox.addWidget(self.eventName)
-        self.nameAddHBox.addWidget(self.addButton)
-        self.inputFieldHBox = QtGui.QHBoxLayout()
-        self.inputField2HBox = QtGui.QHBoxLayout()
-        self.inputFieldHBox.addWidget(self.eventDbusInterface)
-        self.inputFieldHBox.addWidget(self.eventDbusService)
-        self.inputFieldHBox.addWidget(self.eventDbusPath)
-        self.inputFieldHBox.addWidget(self.eventDbusName)
-        self.inputField2HBox.addWidget(self.eventDbusArgs)
-        self.inputFieldHBox.addWidget(self.eventExec)
-        self.inputFieldHBox.addWidget(self.eventBuiltin)
-        self.newEventVBox = QtGui.QVBoxLayout()
-        self.newEventVBox.addLayout(self.dateHBox)
-        self.newEventVBox.addLayout(self.nameAddHBox)
-        self.newEventVBox.addLayout(self.inputFieldHBox)
-        self.newEventVBox.addLayout(self.inputField2HBox)
+        dateHBox = QtGui.QHBoxLayout()
+        dateHBox.addWidget(self.typePicker)
+        dateHBox.addWidget(self.intervalPicker)
+        dateHBox.addWidget(self.dateButton)
+        dateHBox.addWidget(self.weekdayButton)
+        dateHBox.addWidget(self.timeButton)
+        nameAddHBox = QtGui.QHBoxLayout()
+        nameAddHBox.addWidget(self.eventName)
+        nameAddHBox.addWidget(self.addButton)
+        inputFieldHBox = QtGui.QHBoxLayout()
+        inputField2HBox = QtGui.QHBoxLayout()
+        inputFieldHBox.addWidget(self.eventDbusInterface)
+        inputFieldHBox.addWidget(self.eventDbusService)
+        inputFieldHBox.addWidget(self.eventDbusPath)
+        inputFieldHBox.addWidget(self.eventDbusName)
+        inputField2HBox.addWidget(self.eventDbusArgs)
+        inputFieldHBox.addWidget(self.eventExec)
+        inputFieldHBox.addWidget(self.eventBuiltin)
+        newEventVBox = QtGui.QVBoxLayout()
+        newEventVBox.addLayout(dateHBox)
+        newEventVBox.addLayout(nameAddHBox)
+        newEventVBox.addLayout(inputFieldHBox)
+        newEventVBox.addLayout(inputField2HBox)
         
-        self.newEventDialog.setLayout(self.newEventVBox)
+        self.newEventDialog.setLayout(newEventVBox)
         
         # If we're editing, adjust the GUI to the right values
         if (editing):
@@ -184,10 +205,16 @@ class DataCounterResetter(QtGui.QWidget):
              self.eventList.currentItem().eventInfo["typeIndex"])
             dateTime = QtCore.QDateTime.fromTime_t(
              self.eventList.currentItem().eventInfo["ttime"])
+            ###pyside###
             self.datePicker.setCurrentDate(QtCore.QDate.fromString(
                             dateTime.toString("ddMMyyyy"),"ddMMyyyy"))
             self.timePicker.setCurrentTime(QtCore.QTime.fromString(
                             dateTime.toString("hhmm"),"hhmm"))
+            #~ self.dateButton.setDate(QtCore.QDate.fromString(
+                        #~ dateTime.toString("ddMMyyyy"),"ddMMyyyy"))
+            #~ self.timeButton.setTime(QtCore.QTime.fromString(
+                        #~ dateTime.toString("hhmm"),"hhmm"))
+            ###pyside###                
             self.weekdays = (
              self.eventList.currentItem().eventInfo["weekdays"])
             self.eventName.setText(
@@ -221,13 +248,13 @@ class DataCounterResetter(QtGui.QWidget):
             elif self.eventList.currentItem().eventInfo["type"] == (
                                                       builtin_type):
                 self.eventBuiltin.setCurrentIndex(
-                 self.eventList.currentItem().eventInfo["builtinIndex"] )
+                 self.eventList.currentItem().eventInfo["builtinIndex"])
                 self.eventBuiltin.show()
             self.eventName.setText(
              self.eventList.currentItem().eventInfo["title"])
             self.editing = True
         
-        self.newEventDialog.exec_()
+        self.newEventDialog.open()
     
     def generateEventString(self, eventInfo):
         dateTime = QtCore.QDateTime.fromTime_t(eventInfo["ttime"])
@@ -367,6 +394,17 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventExec.hide()
             self.eventBuiltin.show()
 
+    def showError(self, msg=""):
+        ###pyside###
+        banner = QtMaemo5.QMaemo5InformationBox()
+        banner.information(self, msg, 2000)
+        #~ errorDialog = QtGui.QDialog()
+        #~ errorDialog.setWindowTitle("Error")
+        #~ errorHBox = QtGui.QHBoxLayout()
+        #~ errorHBox.addWidget(QtGui.QLabel(msg))
+        #~ errorDialog.setLayout(errorHBox)
+        #~ errorDialog.exec_()
+
     def removeEvent(self):
         if (self.eventList.currentItem()):
             os.remove(self.job_dir +
@@ -376,28 +414,36 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventList.removeItemWidget(
              self.eventList.currentItem())
         else:
-            banner = QtMaemo5.QMaemo5InformationBox()
-            # setting the color as a workaround for a bug in pr1.1 Qt
-            banner.information(self, '''<font color="#000000">Select an item first</font>''', 2000)
+            ###pyside###
+            self.showError('''<font color="#000000">Select an item first</font>''')
+            #~ self.showError("Select an item first")
+            ###pyside###
     
     def editEvent(self):
         if (self.eventList.currentItem()):
             self.addEvent(self.eventList.currentItem())
         else:
-            banner = QtMaemo5.QMaemo5InformationBox()
-            # setting the color as a workaround for a bug in pr1.1 Qt
-            banner.information(self, '''<font color="#000000">Select an item first</font>''', 2000)
+            ###pyside###
+            self.showError('''<font color="#000000">Select an item first</font>''')
+            #~ self.showError("Select an item first")
+            ###pyside###
     
     def setAlarmEvent(self):
         if self.intervalPicker.currentText() in [weekly, biweekly]:
             if not self.weekdays:
-                banner = QtMaemo5.QMaemo5InformationBox()
-                # setting the color as a workaround for a bug in pr1.1 Qt
-                banner.information(self, '''<font color="#000000">Please select at least one week day</font>''', 2000)
+                ###pyside###
+                self.showError('''<font color="#000000">Please select at least one week day</font>''')
+                #~ self.showError("Select an item first")
+                ###pyside###
                 return False
         
+        ###pyside###
         sdate = self.datePicker.currentDate()
         stime = self.timePicker.currentTime()
+        #~ sdate = self.dateButton.date()
+        #~ stime = self.timeButton.time()
+        ###pyside###
+        
         dateTime = QtCore.QDateTime()
         dateTime.setDate(sdate)
         dateTime.setTime(stime)
@@ -426,7 +472,8 @@ class DataCounterResetter(QtGui.QWidget):
         eventInfo["weekdays"] = self.weekdays
         eventInfo["title"] = str(self.eventName.text())
         eventInfo["content"] = content
-        eventInfo["builtinIndex"] = int(self.eventBuiltin.currentIndex()) or 0
+        eventInfo["builtinIndex"] = int(
+                                  self.eventBuiltin.currentIndex()) or 0
         
         dt = datetime.datetime.fromtimestamp(eventInfo["ttime"])
         
@@ -465,6 +512,10 @@ class DataCounterResetter(QtGui.QWidget):
                              alarm.ACTION_TYPE_EXEC)
             if eventInfo["content"] == gprsdataresetter:
                 action.command = str("/opt/alarmed/gprsdataresetter.py")
+            elif eventInfo["content"] == offlineswitcher:
+                action.command = str("/opt/alarmed/offlineswitcher.py")
+            elif eventInfo["content"] == onlineswitcher:
+                action.command = str("/opt/alarmed/onlineswitcher.py")
             
         if eventInfo["interval"] != only_once:
             recurrence = event.add_recurrences(1)[0]
@@ -566,9 +617,10 @@ class DataCounterResetter(QtGui.QWidget):
         try:
             eventInfo["id"] = str(alarm.add_event(event))
         except alarm.InvalidEventException:
-            banner = QtMaemo5.QMaemo5InformationBox()
-            # setting the color as a workaround for a bug in pr1.1 Qt
-            banner.information(self, '''<font color="#000000">Please pick a date & time in the future</font>''', 2000)
+            ###pyside###
+            self.showError('''<font color="#000000">Please pick a date & time in the future</font>''')
+            #~ self.showError("Please pick a date & time in the future")
+            ###pyside###
             return False
             
 
@@ -578,6 +630,15 @@ class DataCounterResetter(QtGui.QWidget):
             self.eventList.currentItem().setText(newEventString)
         else:
             newEvent = QtGui.QListWidgetItem(newEventString)
+            # not possible until shiboken
+            #~ newEventVBox = QtGui.QVBoxLayout()
+            #~ newEventLabel = QtGui.QLabel("Title")
+            #~ newEventWidget = QtGui.QWidget
+            #~ newEventDesc = QtGui.QLabel(newEventString)
+            #~ newEventVBox.addWidget(newEventLabel)
+            #~ newEventVBox.addWidget(newEventDesc)
+            #~ newEventWidget.setLayout(newEventVBox)
+            #~ self.eventList.setIndexWidget(0, newEventHBox)
         
         if self.editing:
             self.eventList.currentItem().eventInfo = eventInfo
